import polars as pl
from polars_maxminddb import ip_lookup_city
from polars_maxminddb import ip_lookup_country
from polars_maxminddb import ip_lookup_asn


def test_city():
    df = pl.DataFrame(
        {
            "ip": ["92.200.50.6", "195.90.212.198", "95.173.223.186", "121.37.156.226"],
        }
    )
    result = df.with_columns(city=ip_lookup_city("ip"))

    expected_df = pl.DataFrame(
        {
            "ip": ["92.200.50.6", "195.90.212.198", "95.173.223.186", "121.37.156.226"],
            "city": ["Sundern", "Frankfurt am Main", "Lima", ""],
        }
    )

    assert result.equals(expected_df)


def test_country():
    df = pl.DataFrame(
        {
            "ip": ["92.200.50.6", "195.90.212.198", "95.173.223.186", "121.37.156.226"],
        }
    )
    result = df.with_columns(country=ip_lookup_country("ip"))

    expected_df = pl.DataFrame(
        {
            "ip": ["92.200.50.6", "195.90.212.198", "95.173.223.186", "121.37.156.226"],
            "country": ["Germany", "Germany", "Peru", "China"],
        }
    )

    assert result.equals(expected_df)


def test_asn():
    df = pl.DataFrame(
        {
            "ip": ["92.200.50.6", "195.90.212.198", "95.173.223.186", "121.37.156.226"],
        }
    )
    result = df.with_columns(asn=ip_lookup_asn("ip"))

    expected_df = pl.DataFrame(
        {
            "ip": ["92.200.50.6", "195.90.212.198", "95.173.223.186", "121.37.156.226"],
            "asn": [
                "Plusnet GmbH",
                "EVANZO e-commerce GmbH",
                "Datacamp Limited",
                "Huawei Cloud Service data center",
            ],
        }
    )

    assert result.equals(expected_df)



import polars as pl
from polars_maxminddb import ip_lookup_city, ip_lookup_country, ip_lookup_asn, ip_lookup_latitude, ip_lookup_longitude

# Example DataFrame with IP addresses
df = pl.DataFrame(
    {
        "ip_addresses": [
            "92.200.50.6",
            "195.90.212.198",
            "95.173.223.186",
            "121.37.156.226",
        ],
    }
)


# Perform city lookup
df = df.with_columns(
    ip_lookup_city(df["ip_addresses"], "GeoLite2-City.mmdb").alias("city")
)

# Perform country lookup
df = df.with_columns(
    ip_lookup_country(df["ip_addresses"], "GeoLite2-City.mmdb").alias("country")
)

# Perform ASN lookup
df = df.with_columns(
    ip_lookup_asn(df["ip_addresses"], "GeoLite2-ASN.mmdb").alias("asn_name")
)

df = df.with_columns(
    ip_lookup_latitude(df["ip_addresses"], "GeoLite2-City.mmdb").alias("latitude"),
    ip_lookup_longitude(df["ip_addresses"], "GeoLite2-City.mmdb").alias("longitude")
)

print(df)



from typing import TYPE_CHECKING, Union

if TYPE_CHECKING:
    import sys
    import polars as pl

    if sys.version_info >= (3, 10):
        from typing import TypeAlias
    else:
        from typing_extensions import TypeAlias
    from polars.datatypes import DataType, DataTypeClass

    IntoExprColumn: TypeAlias = Union[pl.Expr, str, pl.Series]
    PolarsDataType: TypeAlias = Union[DataType, DataTypeClass]



from __future__ import annotations

from pathlib import Path
from typing import TYPE_CHECKING

import polars as pl
from polars.plugins import register_plugin_function

from polars_maxminddb._internal import __version__ as __version__

if TYPE_CHECKING:
    from polars_maxminddb.typing import IntoExprColumn

LIB = Path(__file__).parent


def ip_lookup_city(expr: IntoExprColumn, maxminddb: str) -> pl.Expr:
    return register_plugin_function(
        args=[expr],
        plugin_path=LIB,
        function_name="ip_lookup_city",
        is_elementwise=True,
        kwargs={"maxminddb": maxminddb},
    )


def ip_lookup_latitude(expr: IntoExprColumn, maxminddb: str) -> pl.Expr:
    return register_plugin_function(
        args=[expr],
        plugin_path=LIB,
        function_name="ip_lookup_latitude",
        is_elementwise=True,
        kwargs={"maxminddb": maxminddb},
    )


def ip_lookup_longitude(expr: IntoExprColumn, maxminddb: str) -> pl.Expr:
    return register_plugin_function(
        args=[expr],
        plugin_path=LIB,
        function_name="ip_lookup_longitude",
        is_elementwise=True,
        kwargs={"maxminddb": maxminddb},
    )


def ip_lookup_country(expr: IntoExprColumn, maxminddb: str) -> pl.Expr:
    return register_plugin_function(
        args=[expr],
        plugin_path=LIB,
        function_name="ip_lookup_country",
        is_elementwise=True,
        kwargs={"maxminddb": maxminddb},
    )


def ip_lookup_asn(expr: IntoExprColumn, maxminddb: str) -> pl.Expr:
    return register_plugin_function(
        args=[expr],
        plugin_path=LIB,
        function_name="ip_lookup_asn",
        is_elementwise=True,
        kwargs={"maxminddb": maxminddb},
    )
